@@ -3,6 +3,7 @@ import os
 import queue
 import sys
 import time
+from asyncio.exceptions import CancelledError
 from concurrent.futures import Future
 from time import sleep
 from typing import Any, Callable, Optional, Union
@@ -361,7 +362,10 @@ def execute_tasks_with_dependencies(
             task_dict is not None and "fn" in task_dict and "future" in task_dict
         ):
             future_lst, ready_flag = _get_future_objects_from_input(task_dict=task_dict)
-            if len(future_lst) == 0 or ready_flag:
+            exception_lst = _get_exception_lst(future_lst=future_lst)
+            if len(exception_lst) > 0:
+                task_dict["future"].set_exception(exception_lst[0])
+            elif len(future_lst) == 0 or ready_flag:
                 # No future objects are used in the input or all future objects are already done
                 task_dict["args"], task_dict["kwargs"] = _update_futures_in_input(
                     args=task_dict["args"], kwargs=task_dict["kwargs"]
@@ -455,7 +459,10 @@ def _submit_waiting_task(wait_lst: list[dict], executor_queue: queue.Queue) -> l
     """
     wait_tmp_lst = []
     for task_wait_dict in wait_lst:
-        if all(future.done() for future in task_wait_dict["future_lst"]):
+        exception_lst = _get_exception_lst(future_lst=task_wait_dict["future_lst"])
+        if len(exception_lst) > 0:
+            task_wait_dict["future"].set_exception(exception_lst[0])
+        elif all(future.done() for future in task_wait_dict["future_lst"]):
             del task_wait_dict["future_lst"]
             task_wait_dict["args"], task_wait_dict["kwargs"] = _update_futures_in_input(
                 args=task_wait_dict["args"], kwargs=task_wait_dict["kwargs"]
@@ -663,3 +670,17 @@ def _execute_task_with_cache(
         future = task_dict["future"]
         future.set_result(result)
         future_queue.task_done()
+
+
+def _get_exception_lst(future_lst: list) -> list:
+    def get_exception(future_obj: Future) -> bool:
+        try:
+            excp = future_obj.exception(timeout=10**-10)
+            return excp is not None and not isinstance(excp, CancelledError)
+        except TimeoutError:
+            return False
+
+    if sys.version_info[0] >= 3 and sys.version_info[1] >= 11:
+        return [f.exception() for f in future_lst if get_exception(future_obj=f)]
+    else:
+        return []
